bps_get: bps_get

Description Usage Arguments Value See Also

View source: R/bps_get.R

Description

Download Buildings Permits Survey data

Usage

1
2
bps_get(path, geography = "state", formats = "a", years = NULL,
  months = NULL, regions = NULL, return_log_df = F)

Arguments

path

Character, length 1. Path to directory where data will download.

geography

Character, length 1. Geography (unit of observation) of data to download. One of "state", "county", "msa", or "place".

formats

Character. Format of data to download. Can be any combo or all of "a", "c", "y", or "r". Use bps_doc to get more info from the BPS documentation.

years

Numeric. One or more years for which to download data.

months

Character. DO NOT USE right now. One or more months for which to download data. If NULL, all available months will be downloaded.

regions

Character. Can be any combo or all of "mw", "ne", "so", and "we", or "all".

return_log_df

Logical, length 1.

Value

Downloads data in the background. By default, returns nothing. If return_log_df = TRUE, returns a data frame containing metadata for all files downloaded.

See Also

bps_read


everetr/houser documentation built on May 25, 2020, 9:29 a.m.