Description Usage Arguments Value See Also
Download Buildings Permits Survey data
1 2 |
path |
Character, length 1. Path to directory where data will download. |
geography |
Character, length 1. Geography (unit of observation) of data to download. One of "state", "county", "msa", or "place". |
formats |
Character. Format of data to download. Can be any combo or all
of "a", "c", "y", or "r". Use |
years |
Numeric. One or more years for which to download data. |
months |
Character. DO NOT USE right now. One or more months for which to download data. If NULL, all available months will be downloaded. |
regions |
Character. Can be any combo or all of "mw", "ne", "so", and "we", or "all". |
return_log_df |
Logical, length 1. |
Downloads data in the background. By default, returns nothing. If
return_log_df = TRUE, returns a data frame containing metadata for all
files downloaded.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.